package Yukki::Model;
$Yukki::Model::VERSION = '0.990_001'; # TRIAL

$Yukki::Model::VERSION = '0.990001';use v5.24;
use utf8;
use Moo;

use Type::Utils;

use namespace::clean;

# ABSTRACT: Base class for model objects


has app => (
    is          => 'ro',
    isa         => class_type('Yukki'),
    required    => 1,
    weak_ref    => 1,
    handles     => 'Yukki::Role::App',
);

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Yukki::Model - Base class for model objects

=head1 VERSION

version 0.990_001

=head1 DESCRIPTION

This is the base class used for model objects.

=head1 ATTRIBUTES

=head2 app

This is the L<Yukki> application instance.

=head1 AUTHOR

Andrew Sterling Hanenkamp <hanenkamp@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by Qubling Software LLC.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
